pub struct BlameFrontierGroup {
pub target: BlameTarget,
pub records: Vec<BlameFrontierRecord>,
}Expand description
Canonical LIFO frontier group. Replay of the same group is deterministic.
target is the prepared file this group may attribute. A record bound to
another job’s target is InvalidFrontier, not a silent swap.
Fields
target: BlameTargetrecords: Vec<BlameFrontierRecord>Implementations
Sourceimpl BlameFrontierGroup
impl BlameFrontierGroup
pub fn is_empty(&self) -> bool
pub fn pop(&mut self) -> Option<BlameFrontierRecord>
pub fn push(&mut self, record: BlameFrontierRecord)
Sourcepub fn require_target(
&self,
expected: &BlameTarget,
) -> Result<(), BlameSliceError>
pub fn require_target( &self, expected: &BlameTarget, ) -> Result<(), BlameSliceError>
Fail closed when this group is replayed against a different prepare.
Sourcepub fn require_path(&self, path: &Path) -> Result<(), BlameSliceError>
pub fn require_path(&self, path: &Path) -> Result<(), BlameSliceError>
Fail closed when an advance path is not this group’s prepared path.
pub fn require_consistent_target(&self) -> Result<(), BlameSliceError>