#[repr(transparent)]pub struct RoadMarkingType {
pub repr: i32,
}Expand description
Shared enum representing different types of road markings. This is needed to access the enum variant from Rust API since the C++ enum has an opaque implementation. The order of these variants must match with the order of the enum class defined in maliput C++ API.
Fields
repr: i32Implementations
Sourceimpl RoadMarkingType
impl RoadMarkingType
pub const kStop: Self
pub const kStopLine: Self
pub const kCrosswalk: Self
pub const kParkingSpace: Self
pub const kEmergencyLane: Self
pub const kSpeedLimit: Self
pub const kDoNotStop: Self
pub const kRailRoad: Self
pub const kGiveWay: Self
pub const kArrowTurnRight: Self
pub const kArrowTurnLeft: Self
pub const kArrowForwardTurnRight: Self
pub const kArrowForwardTurnLeft: Self
pub const kArrowForward: Self
pub const kArrowForwardTurnRightTurnLeft: Self
pub const kArrowTurnRightTurnLeft: Self
pub const kArrowUTurnRight: Self
pub const kArrowUTurnLeft: Self
pub const kUnknown: Self