#[repr(transparent)]pub struct RoadMarkingValueUnit {
pub repr: i32,
}Expand description
Shared enum representing the unit of a RoadMarkingValue.
The order of these variants must match with the order of the enum class defined in maliput C++ API.
Fields
repr: i32Implementations
Sourceimpl RoadMarkingValueUnit
impl RoadMarkingValueUnit
pub const kMetersPerSecond: Self
pub const kKilometersPerHour: Self
pub const kMilesPerHour: Self