#[repr(transparent)]pub struct RoadObjectType {
pub repr: i32,
}Expand description
Shared enum representing different types of road objects. This is needed to access the enum variant from Rust API since the C++ enum has an opaque implementation. The order of these variants must match with the order of the enum class defined in maliput C++ API.
Fields
repr: i32Implementations
Sourceimpl RoadObjectType
impl RoadObjectType
pub const kUnknown: Self
pub const kBarrier: Self
pub const kGuardWall: Self
pub const kGuardRail: Self
pub const kBuilding: Self
pub const kGantry: Self
pub const kObstacle: Self
pub const kPole: Self
pub const kTrafficIsland: Self
pub const kTree: Self
pub const kVegetation: Self
pub const kPylon: Self
pub const kDelineator: Self
pub const kBikeStatic: Self
pub const kBusStatic: Self
pub const kCarStatic: Self
pub const kMotorbikeStatic: Self
pub const kPatch: Self
pub const kPedestrianStatic: Self
pub const kRailing: Self
pub const kRoadSurface: Self
pub const kSoundBarrier: Self
pub const kStreetLamp: Self
pub const kTrailerStatic: Self
pub const kTrainStatic: Self
pub const kTramStatic: Self
pub const kVanStatic: Self
pub const kWind: Self