write_file_atomic_reconstructible

Function write_file_atomic_reconstructible 

pub fn write_file_atomic_reconstructible(
    path: &Path,
    bytes: &[u8],
) -> Result<(), Error>
Atomically publish reconstructible bytes without forcing them to stable storage. The final path is never observed partially written, but a crash may lose this write. Callers must have an independent durable source from which the file can be rebuilt.