pub enum MetadataName {
Git,
Heddle,
GitModules,
}Expand description
A name that tree entries must not alias.
Variants
Git
Git’s .git directory, reserved at every depth.
Heddle
Heddle’s .heddle directory, reserved at the root of a tree.
GitModules
Git’s .gitmodules file, reserved as a symlink at every depth.
Implementations