SemanticChange

Enum SemanticChange 

pub enum SemanticChange {
Show 14 variants FileAdded { path: PathBuf, }, FileDeleted { path: PathBuf, }, FileModified { path: PathBuf, classification: Option<ModificationKind>, importance: Option<ChangeImportance>, confidence: Option<f64>, }, FileRenamed { from: PathBuf, to: PathBuf, }, FunctionAdded { file: PathBuf, name: String, importance: Option<ChangeImportance>, }, FunctionExtracted { file: PathBuf, name: String, source_file: Option<PathBuf>, source_name: Option<String>, importance: Option<ChangeImportance>, }, FunctionDeleted { file: PathBuf, name: String, importance: Option<ChangeImportance>, }, FunctionRenamed { file: PathBuf, old_name: String, new_name: String, importance: Option<ChangeImportance>, }, FunctionModified { file: PathBuf, name: String, importance: Option<ChangeImportance>, }, FunctionMoved { file: PathBuf, name: String, old_start_line: usize, new_start_line: usize, importance: Option<ChangeImportance>, }, SignatureChanged { file: PathBuf, name: String, old_signature: String, new_signature: String, importance: Option<ChangeImportance>, }, DependencyAdded { name: String, version: String, }, DependencyRemoved { name: String, }, Custom { change_type: String, data: Value, },
}
A semantic change description.

Variants



FileAdded

A new file was added.

Fields

path: PathBuf


FileDeleted

A file was deleted.

Fields

path: PathBuf


FileModified

A file was modified.

Fields

path: PathBuf
classification: Option<ModificationKind>
confidence: Option<f64>

Confidence in the classification (0.0–1.0). AST-backed = high, token-fallback = lower.



FileRenamed

A file was renamed.

Fields

from: PathBuf


FunctionAdded

A function was added without enough evidence to call it an extraction.

Fields

file: PathBuf
name: String


FunctionExtracted

A function was extracted from an existing function.

Fields

file: PathBuf
name: String
source_file: Option<PathBuf>
source_name: Option<String>


FunctionDeleted

A function was deleted.

Fields

file: PathBuf
name: String


FunctionRenamed

A function was renamed.

Fields

file: PathBuf
old_name: String
new_name: String


FunctionModified

A function body changed without a signature/name change.

Fields

file: PathBuf
name: String


FunctionMoved

A function moved within the same file without changing its body.

Fields

file: PathBuf
name: String
old_start_line: usize
new_start_line: usize


SignatureChanged

A function signature changed.

Fields

file: PathBuf
name: String
old_signature: String
new_signature: String


DependencyAdded

A dependency was added.

Fields

name: String
version: String


DependencyRemoved

A dependency was removed.

Fields

name: String


Custom

Custom semantic change.

Fields

change_type: String
data: Value

Implementations

Source

impl SemanticChange

pub fn description(&self) -> String

Get a short description.