authored_review_requirements

Function authored_review_requirements 

pub fn authored_review_requirements(
    source_scope: &CollaborationScope,
    target_scope: &CollaborationScope,
    review: &Review,
) -> Result<Vec<AuthoredSourceRequirement>, CollaborationCodecError>
Source predicates of a signed review, independent of its current display location. The source and target scopes are explicit because a fork review can compare a source Thread with its independently shared parent Thread.