pub fn decode_redacted_projection(
data: &[u8],
) -> Result<PartialTree, TreeStreamError>Expand description
Decode an HRT1 redacted projection and verify it reconstructs its declared root.
pub fn decode_redacted_projection(
data: &[u8],
) -> Result<PartialTree, TreeStreamError>Decode an HRT1 redacted projection and verify it reconstructs its declared root.