pub fn fsck_manifest<S>(source: &S, root: &ContentHash) -> FsckReportwhere
S: ManifestNodeSource + ?Sized,Expand description
Check a manifest graph rooted at root for structure and digests only.
pub fn fsck_manifest<S>(source: &S, root: &ContentHash) -> FsckReportwhere
S: ManifestNodeSource + ?Sized,Check a manifest graph rooted at root for structure and digests only.