pub struct FsckFinding {
pub rule: FsckRule,
pub node: Option<ContentHash>,
pub detail: String,
}Expand description
One violation: the rule, where it was found, and a human-readable detail.
Fields
rule: FsckRulenode: Option<ContentHash>The manifest node the finding attaches to, when there is one.
detail: StringTrait Implementations
Sourceimpl Clone for FsckFinding
impl Clone for FsckFinding
Sourcefn clone(&self) -> FsckFinding
fn clone(&self) -> FsckFinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FsckFinding
impl Debug for FsckFinding
Sourceimpl Display for FsckFinding
impl Display for FsckFinding
impl Eq for FsckFinding
Sourceimpl PartialEq for FsckFinding
impl PartialEq for FsckFinding
impl StructuralPartialEq for FsckFinding