pub struct ReferenceClosure {
pub snapshot: SourceTargetSnapshot,
pub blobs: BTreeMap<ContentHash, Vec<u8>>,
pub files: BTreeMap<ContentHash, FileResolution>,
pub targets: BTreeMap<ContentHash, TargetResolution>,
}Expand description
Verified closure includes map nodes and resolution records, but does not follow original source revisions or named references into private history.
Fields
snapshot: SourceTargetSnapshotblobs: BTreeMap<ContentHash, Vec<u8>>files: BTreeMap<ContentHash, FileResolution>targets: BTreeMap<ContentHash, TargetResolution>Auto Trait Implementations
impl Freeze for ReferenceClosure
impl RefUnwindSafe for ReferenceClosure
impl Send for ReferenceClosure
impl Sync for ReferenceClosure
impl Unpin for ReferenceClosure
impl UnsafeUnpin for ReferenceClosure
impl UnwindSafe for ReferenceClosure