pub struct AnnotationRevision {
pub revision_id: String,
pub kind: AnnotationKind,
pub content: String,
pub tags: Vec<String>,
pub attribution: String,
pub created_at: i64,
pub source_hash: Option<ContentHash>,
pub created_at_state: Option<ChangeId>,
}Expand description
A single revision of a logical annotation.
Fields
revision_id: Stringkind: AnnotationKindcontent: Stringattribution: Stringcreated_at: i64source_hash: Option<ContentHash>BLAKE3 hash of the source bytes at the annotated scope when created. For File scope: hash of entire file blob. For Symbol/Lines: hash of the relevant byte range.
created_at_state: Option<ChangeId>The State this revision was created against. Enables retrieving the exact source as it was at annotation time.
Implementations
Sourceimpl AnnotationRevision
impl AnnotationRevision
pub fn validate(&self) -> Result<(), ContextError>