pub struct Principal {
pub name: Vec<u8>,
pub email: Vec<u8>,
}Expand description
Human identity accountable for changes.
Fields
name: Vec<u8>Human-readable name bytes, preserved exactly from the source identity.
email: Vec<u8>Email address bytes, preserved exactly from the source identity.
Implementations
Sourceimpl Principal
impl Principal
Sourcepub fn new(name: impl AsRef<[u8]>, email: impl AsRef<[u8]>) -> Principal
pub fn new(name: impl AsRef<[u8]>, email: impl AsRef<[u8]>) -> Principal
Create a new principal.
Sourcepub fn name_lossy(&self) -> Cow<'_, str>
pub fn name_lossy(&self) -> Cow<'_, str>
Return the name as text for display or text-only API boundaries.
Sourcepub fn email_lossy(&self) -> Cow<'_, str>
pub fn email_lossy(&self) -> Cow<'_, str>
Return the email as text for display or text-only API boundaries.