pub struct SourceHistoryLaws { /* private fields */ }Expand description
Proof that a root is Source History and may be checked out, landed, or visited by Git Projection.
The only way to obtain this token is FacetKind::source_history_laws.
Implementations
Sourceimpl SourceHistoryLaws
impl SourceHistoryLaws
pub const fn may_checkout(self) -> bool
pub const fn may_land(self) -> bool
pub const fn git_projection_visits(self) -> bool