pub enum TreeIntegrityEvent<'a> {
EnterTree {
hash: ContentHash,
tree: &'a Tree,
},
BlobLeaf {
entry: &'a TreeEntry,
path: String,
},
TreeRef {
parent_hash: ContentHash,
entry: &'a TreeEntry,
},
}Expand description
Events emitted while walking reachable trees for integrity checks.
Variants
EnterTree
A tree was entered for the first time during this walk.
BlobLeaf
A blob file entry at path (symlinks and gitlinks are excluded).
TreeRef
A child tree entry from parent_hash.