Module observe

Module observe 

Structured progress and warning channels for library callers.

Structs

CollectingWarnings
Warning sink useful for embedders and tests that need to inspect warnings.
NoopProgress
Default progress sink for callers that do not care about progress.
NoopWarnings
Default warning sink for callers that do not care about warnings.
TaskId
Stable progress task identifier.
Warning
Structured warning for embedders and render layers.

Enums

ProgressEvent
Structured progress event emitted by long-running operations.

Traits

ProgressSink
Receives structured progress events.
WarningSink
Receives structured warnings that should not be printed by domain crates.