Module actor_presence

Module actor_presence 

Durable actor presence and work-context records.

Structs

ActorChainNode
One hop in an actor ancestry chain, ordered root to leaf.
ActorPresence
A registry entry describing one active (or recently finished) agent session.
ActorPresenceStore
Manages actor presence stored in .heddle/actor-presence/.
AgentUsageSummary
ContextQueryEntry
A record of one heddle context get call made during an agent session.

Enums

ActorPresenceStatus
Status of an agent session.

Functions

generate_actor_session_id
Generate a unique agent session identifier.