pub struct ActorChainNode {
pub session_id: String,
pub native_actor_key: Option<String>,
pub native_parent_actor_key: Option<String>,
pub thread: String,
pub status: AgentStatus,
pub provider: Option<String>,
pub model: Option<String>,
pub harness: Option<String>,
}Expand description
One hop in an actor ancestry chain, ordered root to leaf.
Fields
session_id: Stringnative_actor_key: Option<String>native_parent_actor_key: Option<String>thread: Stringstatus: AgentStatusprovider: Option<String>model: Option<String>harness: Option<String>Trait Implementations
Sourceimpl Clone for ActorChainNode
impl Clone for ActorChainNode
Sourcefn clone(&self) -> ActorChainNode
fn clone(&self) -> ActorChainNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActorChainNode
impl Debug for ActorChainNode
Sourceimpl<'de> Deserialize<'de> for ActorChainNode
impl<'de> Deserialize<'de> for ActorChainNode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ActorChainNode
Sourceimpl From<&AgentEntry> for ActorChainNode
impl From<&AgentEntry> for ActorChainNode
Sourcefn from(entry: &AgentEntry) -> Self
fn from(entry: &AgentEntry) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ActorChainNode
impl PartialEq for ActorChainNode
Sourcefn eq(&self, other: &ActorChainNode) -> bool
fn eq(&self, other: &ActorChainNode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ActorChainNode
impl Serialize for ActorChainNode
impl StructuralPartialEq for ActorChainNode