AgentEntry

Struct AgentEntry 

pub struct AgentEntry {
Show 33 fields pub session_id: String, pub client_instance_id: Option<String>, pub native_actor_key: Option<String>, pub native_parent_actor_key: Option<String>, pub native_instance_key: Option<String>, pub heddle_session_id: Option<String>, pub thread_id: Option<String>, pub thread: String, pub pid: Option<u32>, pub boot_id: Option<String>, pub liveness_path: Option<PathBuf>, pub heartbeat_at: Option<DateTime<Utc>>, pub anchor_state: Option<String>, pub anchor_root: Option<String>, pub reservation_token: Option<String>, pub path: Option<PathBuf>, pub base_state: String, pub started_at: DateTime<Utc>, pub provider: Option<String>, pub model: Option<String>, pub harness: Option<String>, pub thinking_level: Option<String>, pub usage_summary: AgentUsageSummary, pub last_progress_at: Option<DateTime<Utc>>, pub report_flush_state: Option<String>, pub attach_reason: Option<String>, pub attach_precedence: Vec<String>, pub winning_attach_rule: Option<String>, pub probe_source: Option<String>, pub probe_confidence: Option<f32>, pub status: AgentStatus, pub completed_at: Option<DateTime<Utc>>, pub context_queries: Vec<ContextQueryEntry>,
}
A registry entry describing one active (or recently finished) agent session.

Fields

session_id: String

Unique session identifier (e.g. agent-xxxxxxxxxxxx).

client_instance_id: Option<String>

Stable harness-side instance identifier used to reconnect the same local client process to its registry entry across bridge restarts.

native_actor_key: Option<String>

Harness-native actor identity such as codex:thread:thr_123.

native_parent_actor_key: Option<String>

Harness-native parent actor identity for child/subagent sessions.

native_instance_key: Option<String>

Harness-native reconnect key such as a transcript path or client name.

heddle_session_id: Option<String>

Heddle session identifier when this registry entry is attached to a first-class Heddle multi-segment session.

thread_id: Option<String>

Thread identifier when the session is attached to a Heddle thread record.

thread: String

The Heddle thread the agent writes to.

pid: Option<u32>

Process id that created or last renewed the reservation.

boot_id: Option<String>

Host boot identifier when available; differentiates reused PIDs.

liveness_path: Option<PathBuf>

Advisory liveness lock file path for future long-lived runners.

heartbeat_at: Option<DateTime<Utc>>

Most recent reservation heartbeat.

anchor_state: Option<String>

Full state id the session was anchored to.

anchor_root: Option<String>

Root tree id the session was anchored to.

reservation_token: Option<String>

Opaque token returned to programmatic agent clients.

path: Option<PathBuf>

Absolute path to the agent’s checkout directory, if filesystem-based.

base_state: String

Short display form of the base state the agent started from.

started_at: DateTime<Utc>

When the agent session was created.

provider: Option<String>

AI provider (e.g. anthropic).

model: Option<String>

AI model (e.g. claude-sonnet-4-6).

harness: Option<String>

Harness or client name (e.g. claude-code, codex).

thinking_level: Option<String>

Harness-specific reasoning/thinking level when available.

usage_summary: AgentUsageSummary

Aggregated usage counters captured for the active session.

last_progress_at: Option<DateTime<Utc>>

Most recent progress heartbeat timestamp.

report_flush_state: Option<String>

Summary flush state for the local session reporter.

attach_reason: Option<String>

Most recent explanation of why Heddle attached this actor to its current thread/session context.

attach_precedence: Vec<String>

Ordered explanation of attach rules Heddle evaluated.

winning_attach_rule: Option<String>

The attach rule that won for this actor.

probe_source: Option<String>

Where Heddle learned the harness identity from.

probe_confidence: Option<f32>

How confident Heddle was in the probe result.

status: AgentStatus

Current status.

completed_at: Option<DateTime<Utc>>

When the agent was marked complete or merged.

context_queries: Vec<ContextQueryEntry>

Log of heddle context get calls made during this session. Appended by the CLI each time an agent queries context from its worktree.