pub struct RepackInventory {
pub loose_objects: u64,
pub loose_bytes: u64,
pub pack_count: u64,
pub pack_bytes: u64,
pub duplicate_objects: u64,
pub packed_objects: u64,
}Expand description
Cheap storage facts used to decide whether a repack is worthwhile.
Fields
loose_objects: u64Objects currently stored loose.
loose_bytes: u64On-disk bytes occupied by loose objects.
pack_count: u64Active pack count.
pack_bytes: u64Bytes occupied by active pack and index files.
duplicate_objects: u64Pack entries whose identity also occurs in another active pack.
packed_objects: u64Total entries across active packs, including duplicates.
Implementations
Sourceimpl RepackInventory
impl RepackInventory
Sourcepub fn fragmentation_bps(self) -> u16
pub fn fragmentation_bps(self) -> u16
Duplicate-entry fragmentation in basis points (10_000 == 100%).