ObjectCacheControl

Trait ObjectCacheControl 

pub trait ObjectCacheControl: Send + Sync {
    // Required method
    fn clear_recent_caches(&self);
}
Explicit cache control for benchmarks and diagnostic tools.

Cache invalidation is not part of durable object storage semantics. Keeping it separate prevents remote stores such as Weft’s backend from having to pretend they expose process-local cache controls merely to implement ObjectStore.

Required Methods

fn clear_recent_caches(&self)

Drop process-local decoded-object caches, if this implementation has any. The next read should observe the implementation’s cold path.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors