pub struct RoadMarking<'a> { /* private fields */ }Expand description
Models a physical road marking (e.g. stop line, crosswalk, arrow) in the road network.
Implementations
Sourceimpl<'a> RoadMarking<'a>
impl<'a> RoadMarking<'a>
Sourcepub fn name(&self) -> Option<String>
pub fn name(&self) -> Option<String>
Returns the optional human-readable name of this road marking.
Sourcepub fn marking_type(&self) -> RoadMarkingType
pub fn marking_type(&self) -> RoadMarkingType
Returns the RoadMarkingType of this road marking.
Sourcepub fn position(&self) -> RoadObjectPosition
pub fn position(&self) -> RoadObjectPosition
Returns the RoadObjectPosition of this road marking.
Sourcepub fn orientation(&self) -> Rotation
pub fn orientation(&self) -> Rotation
Returns the orientation of this road marking in the inertial frame.
Sourcepub fn bounding_box(&self) -> BoundingBox
pub fn bounding_box(&self) -> BoundingBox
Returns the bounding box of this road marking.
Returns the IDs of lanes related to this road marking.
Sourcepub fn num_outlines(&self) -> i32
pub fn num_outlines(&self) -> i32
Returns the number of outlines of this road marking.
Sourcepub fn value(&self) -> Option<RoadMarkingValue>
pub fn value(&self) -> Option<RoadMarkingValue>
Returns the numeric value (with unit) associated with this road marking, if any.