pub struct RoadObject<'a> { /* private fields */ }Expand description
Models a physical road object in the road network.
A RoadObject has a type, position, orientation, bounding box, and optional
outlines and properties.
Implementations
Sourceimpl<'a> RoadObject<'a>
impl<'a> RoadObject<'a>
Sourcepub fn name(&self) -> Option<String>
pub fn name(&self) -> Option<String>
Returns the optional human-readable name of this road object.
Sourcepub fn object_type(&self) -> RoadObjectType
pub fn object_type(&self) -> RoadObjectType
Returns the RoadObjectType of this road object.
Sourcepub fn subtype(&self) -> Option<String>
pub fn subtype(&self) -> Option<String>
Returns the optional subtype string of this road object.
Sourcepub fn position(&self) -> RoadObjectPosition
pub fn position(&self) -> RoadObjectPosition
Returns the RoadObjectPosition of this road object.
Sourcepub fn orientation(&self) -> Rotation
pub fn orientation(&self) -> Rotation
Returns the orientation of this road object in the inertial frame.
Sourcepub fn bounding_box(&self) -> BoundingBox
pub fn bounding_box(&self) -> BoundingBox
Returns the bounding box of this road object.
Sourcepub fn is_dynamic(&self) -> bool
pub fn is_dynamic(&self) -> bool
Returns whether this road object is dynamic (i.e., may change position or state).
Sourcepub fn is_movable(&self) -> bool
pub fn is_movable(&self) -> bool
Returns whether this road object’s position can change.
Returns the IDs of lanes related to this road object.
Sourcepub fn num_outlines(&self) -> i32
pub fn num_outlines(&self) -> i32
Returns the number of outlines of this road object.
Sourcepub fn properties(&self) -> HashMap<String, String>
pub fn properties(&self) -> HashMap<String, String>
Returns the key-value properties of this road object.