RoadObjectBook

Struct RoadObjectBook 

pub struct RoadObjectBook<'a> { /* private fields */ }
Interface for accessing RoadObjects in the road network.

Implementations

Source

impl<'a> RoadObjectBook<'a>

pub fn road_objects(&self) -> Vec<RoadObject<'_>>

Returns all RoadObjects in the book.

pub fn get_road_object(&self, id: &String) -> Option<RoadObject<'_>>

Returns the RoadObject with the given id, or None if not found.

pub fn find_by_type(&self, obj_type: &RoadObjectType) -> Vec<RoadObject<'_>>

Returns all RoadObjects of the given RoadObjectType.

pub fn find_by_lane(&self, lane_id: &String) -> Vec<RoadObject<'_>>

Returns all RoadObjects whose related_lanes() includes the given lane ID.

pub fn find_in_radius( &self, x: f64, y: f64, z: f64, radius: f64, ) -> Vec<RoadObject<'_>>

Returns all RoadObjects within radius meters of position (x, y, z). If the road object has continuous properties, it will check for all sampled points of the continuous object.