pub struct ThreadConfidenceSummary {
pub value: Option<f32>,
pub band: Option<ConfidenceBand>,
}Fields
value: Option<f32>band: Option<ConfidenceBand>Trait Implementations
Sourceimpl Clone for ThreadConfidenceSummary
impl Clone for ThreadConfidenceSummary
Sourceimpl Debug for ThreadConfidenceSummary
impl Debug for ThreadConfidenceSummary
Sourceimpl Default for ThreadConfidenceSummary
impl Default for ThreadConfidenceSummary
Sourceimpl<'de> Deserialize<'de> for ThreadConfidenceSummary
impl<'de> Deserialize<'de> for ThreadConfidenceSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ThreadConfidenceSummary
impl JsonSchema for ThreadConfidenceSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadConfidenceSummary
impl RefUnwindSafe for ThreadConfidenceSummary
impl Send for ThreadConfidenceSummary
impl Sync for ThreadConfidenceSummary
impl Unpin for ThreadConfidenceSummary
impl UnsafeUnpin for ThreadConfidenceSummary
impl UnwindSafe for ThreadConfidenceSummary