pub struct ThreadVerificationSummary {
pub tests_passed: Option<bool>,
pub tests_failed: Option<u32>,
pub coverage_pct: Option<f32>,
pub lint_warnings: Option<u32>,
}Fields
tests_passed: Option<bool>tests_failed: Option<u32>coverage_pct: Option<f32>lint_warnings: Option<u32>Trait Implementations
Sourceimpl Clone for ThreadVerificationSummary
impl Clone for ThreadVerificationSummary
Sourceimpl Debug for ThreadVerificationSummary
impl Debug for ThreadVerificationSummary
Sourceimpl Default for ThreadVerificationSummary
impl Default for ThreadVerificationSummary
Sourceimpl<'de> Deserialize<'de> for ThreadVerificationSummary
impl<'de> Deserialize<'de> for ThreadVerificationSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ThreadVerificationSummary
impl JsonSchema for ThreadVerificationSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadVerificationSummary
impl RefUnwindSafe for ThreadVerificationSummary
impl Send for ThreadVerificationSummary
impl Sync for ThreadVerificationSummary
impl Unpin for ThreadVerificationSummary
impl UnsafeUnpin for ThreadVerificationSummary
impl UnwindSafe for ThreadVerificationSummary