Builder

Trait Builder 

pub trait Builder {
    type Error;

    // Required methods
    fn mime_type(&self) -> String;
    fn build<W: Write>(&self, buf: W) -> Result<(), Self::Error>;
}
A builder type can build a Document Type object into raw bytes of encoded data.

Required Associated Types

Required Methods

fn mime_type(&self) -> String

fn build<W: Write>(&self, buf: W) -> Result<(), Self::Error>

Builds self into raw bytes of the specific Document Type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors