symlink_target_bytes

Function symlink_target_bytes 

pub fn symlink_target_bytes(target: &Path) -> Vec<u8> 
The bytes git would store as a symlink’s blob: the raw OS bytes of the link target. On non-Unix platforms the target is text and lossy conversion is acceptable because the filesystem does not preserve arbitrary bytes.