#[repr(transparent)]pub struct RoadObjectType {
pub repr: i32,
}Expand description
Shared enum representing different types of road objects. This is needed to access the enum variant from Rust API since the C++ enum has an opaque implementation. The order of these variants must match with the order of the enum class defined in maliput C++ API.
Fields
repr: i32Implementations
Sourceimpl RoadObjectType
impl RoadObjectType
pub const kUnknown: Self
pub const kBarrier: Self
pub const kBuilding: Self
pub const kCrosswalk: Self
pub const kGantry: Self
pub const kObstacle: Self
pub const kParkingSpace: Self
pub const kPole: Self
pub const kRoadMark: Self
pub const kRoadSurface: Self
pub const kStopLine: Self
pub const kTrafficIsland: Self
pub const kTree: Self
pub const kVegetation: Self