pub fn write_file_beneath(
root: &Path,
path: &Path,
bytes: &[u8],
) -> Result<File, Error>Expand description
Write bytes to the tracked file path beneath root: parents become
real directories, a leaf symlink is replaced, nothing is followed.