FsStore

Struct FsStore 

pub struct FsStore { /* private fields */ }
Filesystem-based storage for Heddle objects.

Layout:

.heddle/
  objects/
    blobs/
      ab/
        cdef1234...
    trees/
      ab/
        cdef1234...
    states/
      <change_id>.state
  actions/
    <action_id>.action
  packs/
    <hash>.pack
    <hash>.idx

Implementations

Source

impl FsStore

pub fn new(root: impl AsRef<Path>) -> Self

Create a new filesystem store rooted at the given path.

The path should be the .heddle directory.

pub fn with_compression( root: impl AsRef<Path>, compression: CompressionConfig, ) -> Self

Create a new filesystem store with custom compression settings.

pub fn init(&self) -> Result<()>

Initialize the directory structure.

pub fn root(&self) -> &Path

Get the root path.

pub fn compression(&self) -> CompressionConfig

Get the compression configuration.

pub fn set_compression(&mut self, compression: CompressionConfig)

Set the compression configuration.

pub fn loose_object_write_mode(&self) -> LooseObjectWriteMode

pub fn set_loose_object_write_mode(&mut self, mode: LooseObjectWriteMode)

pub fn reload_packs(&self) -> Result<()>

Reload pack files from disk.

pub fn pack_manager(&self) -> &RwLock<PackManager>

Get the pack manager for pack operations.

pub fn clear_recent_object_caches(&self)

pub fn pack_ids(&self) -> Result<Vec<PackObjectId>>