pub struct FsStore { /* private fields */ }Expand description
Filesystem-based storage for Heddle objects.
Layout:
.heddle/
objects/
blobs/
ab/
cdef1234...
trees/
ab/
cdef1234...
states/
<change_id>.state
actions/
<action_id>.action
packs/
<hash>.pack
<hash>.idxImplementations
Sourceimpl FsStore
impl FsStore
Sourcepub fn new(root: impl AsRef<Path>) -> Self
pub fn new(root: impl AsRef<Path>) -> Self
Create a new filesystem store rooted at the given path.
The path should be the .heddle directory.
Sourcepub fn with_compression(
root: impl AsRef<Path>,
compression: CompressionConfig,
) -> Self
pub fn with_compression( root: impl AsRef<Path>, compression: CompressionConfig, ) -> Self
Create a new filesystem store with custom compression settings.
Sourcepub fn compression(&self) -> CompressionConfig
pub fn compression(&self) -> CompressionConfig
Get the compression configuration.
Sourcepub fn set_compression(&mut self, compression: CompressionConfig)
pub fn set_compression(&mut self, compression: CompressionConfig)
Set the compression configuration.
pub fn loose_object_write_mode(&self) -> LooseObjectWriteMode
pub fn set_loose_object_write_mode(&mut self, mode: LooseObjectWriteMode)
Sourcepub fn reload_packs(&self) -> Result<()>
pub fn reload_packs(&self) -> Result<()>
Reload pack files from disk.
Sourcepub fn pack_manager(&self) -> &RwLock<PackManager>
pub fn pack_manager(&self) -> &RwLock<PackManager>
Get the pack manager for pack operations.
pub fn clear_recent_object_caches(&self)
pub fn pack_ids(&self) -> Result<Vec<PackObjectId>>