pub struct RoadObjectBook<'a> { /* private fields */ }Expand description
Interface for accessing RoadObjects in the road network.
Implementations
Sourceimpl<'a> RoadObjectBook<'a>
impl<'a> RoadObjectBook<'a>
Sourcepub fn road_objects(&self) -> Vec<RoadObject<'_>>
pub fn road_objects(&self) -> Vec<RoadObject<'_>>
Returns all RoadObjects in the book.
Sourcepub fn get_road_object(&self, id: &String) -> Option<RoadObject<'_>>
pub fn get_road_object(&self, id: &String) -> Option<RoadObject<'_>>
Returns the RoadObject with the given id, or None if not found.
Sourcepub fn find_by_type(&self, obj_type: &RoadObjectType) -> Vec<RoadObject<'_>>
pub fn find_by_type(&self, obj_type: &RoadObjectType) -> Vec<RoadObject<'_>>
Returns all RoadObjects of the given RoadObjectType.
Sourcepub fn find_by_lane(&self, lane_id: &String) -> Vec<RoadObject<'_>>
pub fn find_by_lane(&self, lane_id: &String) -> Vec<RoadObject<'_>>
Returns all RoadObjects whose related_lanes() includes the given lane ID.
Sourcepub fn find_in_radius(
&self,
x: f64,
y: f64,
z: f64,
radius: f64,
) -> Vec<RoadObject<'_>>
pub fn find_in_radius( &self, x: f64, y: f64, z: f64, radius: f64, ) -> Vec<RoadObject<'_>>
Returns all RoadObjects within radius meters of position (x, y, z).
If the road object has continuous properties, it will check for all sampled points of the continuous object.