Transfer planning for Heddle object lanes.
One vocabulary for local sync, hosted sync, and the wire protocol: content-addressed objects that can ride the native pack, and signed sidecars that must use the out-of-pack verification paths.
Re-exports
pub use availability::ObjectAvailabilityPlan;pub use availability::has_object;pub use availability::plan_object_availability;pub use graph::ObjectId;pub use graph::ObjectInfo;pub use graph::ObjectType;pub use graph::ObjectTypeBucket;pub use graph::PlannedObject;pub use graph::StateClosureOptions;pub use graph::StateClosureTransferObjects;pub use graph::enumerate_state_closure;pub use graph::enumerate_state_closure_plan;pub use graph::enumerate_state_closure_plan_with_options;pub use graph::enumerate_state_closure_transfer_from_boundaries;pub use graph::enumerate_state_closure_transfer_with_options;pub use graph::enumerate_state_closure_with_options;pub use graph::is_ancestor;pub use graph::missing_blobs_in_tree;pub use plan::GitLaneTransferIntent;pub use plan::RepositoryTransferPlan;pub use plan::TransferPartitions;pub use plan::TransferPlanStats;
Modules
- availability
- graph
- plan
- Shared repository transfer planning primitives.